Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'build_files/cmake/Modules/FindSndFile.cmake')
-rw-r--r--build_files/cmake/Modules/FindSndFile.cmake40
1 files changed, 20 insertions, 20 deletions
diff --git a/build_files/cmake/Modules/FindSndFile.cmake b/build_files/cmake/Modules/FindSndFile.cmake
index 3b4ab38e842..ef6fb73598f 100644
--- a/build_files/cmake/Modules/FindSndFile.cmake
+++ b/build_files/cmake/Modules/FindSndFile.cmake
@@ -1,15 +1,15 @@
# - Find SndFile library
# Find the native SndFile includes and library
# This module defines
# SNDFILE_INCLUDE_DIRS, where to find sndfile.h, Set when
# SNDFILE_INCLUDE_DIR is found.
# SNDFILE_LIBRARIES, libraries to link against to use SndFile.
# SNDFILE_ROOT_DIR, The base directory to search for SndFile.
# This can also be an environment variable.
# SNDFILE_FOUND, If false, do not try to use SndFile.
#
# also defined, but not for general use are
# SNDFILE_LIBRARY, where to find the SndFile library.
#=============================================================================
# Copyright 2011 Blender Foundation.
@@ -22,26 +22,26 @@
# See the License for more information.
#=============================================================================
-# If SNDFILE_ROOT_DIR was defined in the environment, use it.
-IF(NOT SNDFILE_ROOT_DIR AND NOT $ENV{SNDFILE_ROOT_DIR} STREQUAL "")
- SET(SNDFILE_ROOT_DIR $ENV{SNDFILE_ROOT_DIR})
+# If LIBSNDFILE_ROOT_DIR was defined in the environment, use it.
+IF(NOT LIBSNDFILE_ROOT_DIR AND NOT $ENV{LIBSNDFILE_ROOT_DIR} STREQUAL "")
+ SET(LIBSNDFILE_ROOT_DIR $ENV{LIBSNDFILE_ROOT_DIR})
ENDIF()
SET(_sndfile_SEARCH_DIRS
- ${SNDFILE_ROOT_DIR}
+ ${LIBSNDFILE_ROOT_DIR}
/usr/local
/sw # Fink
/opt/local # DarwinPorts
)
-FIND_PATH(SNDFILE_INCLUDE_DIR sndfile.h
+FIND_PATH(LIBSNDFILE_INCLUDE_DIR sndfile.h
HINTS
${_sndfile_SEARCH_DIRS}
PATH_SUFFIXES
include
)
-FIND_LIBRARY(SNDFILE_LIBRARY
+FIND_LIBRARY(LIBSNDFILE_LIBRARY
NAMES
sndfile
HINTS
@@ -50,18 +50,18 @@ FIND_LIBRARY(SNDFILE_LIBRARY
lib64 lib
)
# handle the QUIETLY and REQUIRED arguments and set SNDFILE_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)
FIND_PACKAGE_HANDLE_STANDARD_ARGS(SndFile DEFAULT_MSG
- SNDFILE_LIBRARY SNDFILE_INCLUDE_DIR)
+ LIBSNDFILE_LIBRARY LIBSNDFILE_INCLUDE_DIR)
-IF(SNDFILE_FOUND)
- SET(SNDFILE_LIBRARIES ${SNDFILE_LIBRARY})
- SET(SNDFILE_INCLUDE_DIRS ${SNDFILE_INCLUDE_DIR})
-ENDIF(SNDFILE_FOUND)
+IF(LIBSNDFILE_FOUND)
+ SET(LIBSNDFILE_LIBRARIES ${LIBSNDFILE_LIBRARY})
+ SET(LIBSNDFILE_INCLUDE_DIRS ${LIBSNDFILE_INCLUDE_DIR})
+ENDIF(LIBSNDFILE_FOUND)
MARK_AS_ADVANCED(
- SNDFILE_INCLUDE_DIR
- SNDFILE_LIBRARY
+ LIBSNDFILE_INCLUDE_DIR
+ LIBSNDFILE_LIBRARY
)
@@ -1,15 +1,15 @@
# Find the native SndFile includes and library
# This module defines
-# SNDFILE_INCLUDE_DIRS, where to find sndfile.h, Set when
-# SNDFILE_INCLUDE_DIR is found.
-# SNDFILE_LIBRARIES, libraries to link against to use SndFile.
-# SNDFILE_ROOT_DIR, The base directory to search for SndFile.
+# LIBSNDFILE_INCLUDE_DIRS, where to find sndfile.h, Set when
+# LIBSNDFILE_INCLUDE_DIR is found.
+# LIBSNDFILE_LIBRARIES, libraries to link against to use SndFile.
+# LIBSNDFILE_ROOT_DIR, The base directory to search for SndFile.
# This can also be an environment variable.
@@ -1,15 +1,15 @@
# This can also be an environment variable.
-# SNDFILE_FOUND, If false, do not try to use SndFile.
+# LIBSNDFILE_FOUND, If false, do not try to use SndFile.
#
# also defined, but not for general use are
@@ -1,15 +1,15 @@
#
# also defined, but not for general use are
-# SNDFILE_LIBRARY, where to find the SndFile library.
+# LIBSNDFILE_LIBRARY, where to find the SndFile library.
#=============================================================================
# Copyright 2011 Blender Foundation.
@@ -50,18 +50,18 @@ FIND_LIBRARY(SNDFILE_LIBRARY
lib64 lib
)
-# handle the QUIETLY and REQUIRED arguments and set SNDFILE_FOUND to TRUE if
+# handle the QUIETLY and REQUIRED arguments and set LIBSNDFILE_FOUND to TRUE if
# all listed variables are TRUE
INCLUDE(FindPackageHandleStandardArgs)